Learn R Programming

animint (version 2016.07.12)

VariantModels: Error rates of supervised learning methods for variant calling

Description

Several supervised machine learning models were applied to the binary classification task of predicting True Positive or False Positive variants, using several filtering scores as input.

Usage

data("VariantModels")

Arguments

Format

List of 6 data.frames: roc, auc, error, ranks, thresholds, minima.

https://github.com/tdhock/malaria-evolution-viz/blob/master/figure-folds.R