Format
A list of 5 data.frames: error contains the breakpointError of the
estimated models, signals contains the noisy signals, breaks contains
the breakpoints in the estimated signals, segments contains the
estimated segments, and imprecision contains the normalized imprecision
curves which were used to evaluate the error.Source
The breakpointError package was used to measure the model error, see
etc/breakpoints.R.