Format
List of 4 data.frames: coefs contains the coefficients for every
variable at every point in the regularization path,
truth contains information about which
variables are real changes, likelihood contains the train and test
likelihood, and position contains positions for laying out the graphical
model nodes on the 2D plane.Source
Song Liu, personal communication.