Learn R Programming

animint (version 2016.07.12)

climate: Climate data in central America from 1995 to 2000

Description

Monthly observations of atmospheric variables 1995-2000, between 113.75W-56.25W, 21.25S-36.25N with 2.5 degree grid spacing. Variables: pressure, temperature, ozone and low, medium, high cloud cover. Temperatures are given in degrees celsius (original data had Kelvin).

Usage

data(climate)

Arguments

Format

A data frame with 41472 observations on the following 16 variables.

NASA Goddard Institute for Space Studies (GISS) subset of the monthly climatology of the International Satellite Cloud Climatology Project (ISCCP)