Learn R Programming

animint (version 2016.07.12)

geom_widerect: ggplot2 geom with ymin and ymax aesthetics that covers the entire x range, useful for clickSelects background elements.

Description

ggplot2 geom with ymin and ymax aesthetics that covers the entire x range, useful for clickSelects background elements.

Usage

geom_widerect(mapping = NULL, data = NULL, stat = "identity", position = "identity", ..., na.rm = FALSE, show.legend = NA, inherit.aes = TRUE)

Arguments

mapping
aesthetic mapping
data
data set
stat
statistic mapping, defaults to identity
position
position mapping, defaults to identity
...
other arguments

Value

ggplot2 layer

Examples

Run this code
 ## Not run:  
#    source(system.file("examples/WorldBank.R", package = "animint"))
#  ## End(Not run)

Run the code above in your browser using DataLab