Learn R Programming

animint (version 2016.07.12)

getCommonChunk: Save the common columns for each tsv to one chunk

Description

Save the common columns for each tsv to one chunk

Usage

getCommonChunk(built, chunk.vars, aes.list)

Arguments

built
data.frame of built data.
aes.list
a character vector of aesthetics.
vars
character vector of chunk variable names to split on.

Value

a list of common and varied data to save, or NULL if there is no common data.