Format
There are 7 related data.frames: signals contains the noisy
piecewise constant signals, annotations contains the weak labels,
segments and breaks contain the segmentation model, selection contains
the penalty and cost information, intervals contains the target
intervals of penalty values for each signal, and model describes the
learned max margin interval regression model.