Rdocumentation
powered by
Learn R Programming
animint (version 2016.07.12)
parsePlot: Convert a ggplot to a list.
Description
Convert a ggplot to a list.
Usage
parsePlot(meta)
Arguments
meta
environment with previously calculated plot data, and a new plot to parse, already stored in plot and plot.name.
Value
nothing, info is stored in meta.