Learn R Programming

animint (version 2016.07.12)

renderAnimint: Create an animint output element

Description

Shiny server output function customized for animint plots (similar to shiny::plotOutput and friends).

Usage

renderAnimint(expr, env = parent.frame(), quoted = FALSE)

Arguments

expr
An expression that creates a list of ggplot objects.
env
The environment in which to evaluate expr.
quoted
Is expr a quoted expression (with quote())? This is useful if you want to save an expression in a variable.

See Also

http://shiny.rstudio.com/articles/building-outputs.html