Learn R Programming

animint (version 2016.07.12)

saveLayer: Save a layer to disk, save and return meta-data.

Description

Save a layer to disk, save and return meta-data.

Usage

saveLayer(l, d, meta)

Arguments

l
one layer of the ggplot object.
d
one layer of calculated data from ggplot2::ggplot_build(p).
meta
environment of meta-data.

Value

list representing a layer, with corresponding aesthetics, ranges, and groups.