Learn R Programming

animint (version 2016.07.12)

tests_run: Run animint tests

Description

Convenience function for running animint tests.

Usage

tests_run(dir = ".", filter = NULL)

Arguments

dir
character string with the path to animint's source code. Defaults to current directory
filter
If not NULL, only tests with file names matching this regular expression will be executed. Matching will take on the file name after it has been stripped of "test-" and ".r".

Examples

Run this code

## Not run: 
# # run tests in test-rotate.R with Firefox
# tests_init("firefox")
# tests_run(filter = "rotate")
# # clean-up
# tests_exit()
# ## End(Not run)

Run the code above in your browser using DataLab