Format
The format is a named list of data.frames: samples contains 64 rows
with sample-specific info, counts contains 1190208 rows with counts of
55mers observed in each sample, and monkeys contains 23 rows with
monkey-specific information.Source
DNA sequencing was funded by Genome Quebec and generated at the McGill
Innovation Center. More info about the Vervet Microbiome project
http://www.genomequebec.mcgill.ca/compgen/vervet_research/
http://genome.wustl.edu/projects/detail/vervet-microbiome/