Rdocumentation
powered by
Learn R Programming
animint (version 2016.07.12)
saveChunks: Split data set into chunks and save them to separate files.
Description
Split data set into chunks and save them to separate files.
Usage
saveChunks(x, meta)
Arguments
x
data.frame.
meta
environment.
Value
recursive list of chunk file names.