worldPop:
World population by subcontinent
Description
World population data are used as a simple example on the polychart.js
website, and so these data can be used to recreate that example using animint.
Format
A data frame with 294 observations on the following 4 variables.
https://github.com/Polychart/polychart2/blob/master/example/population.coffee